@@ -75,7 +75,7 @@ class SchemeOpt(object):
     Update = "update"
     UEFI = "uefi"
     LVM = "lvm"
-    Calculate = "calculate"
+    Calculate = "data"
 
 
 class AutopartitionHelper(VariableInterface):
@@ -522,7 +522,7 @@ class VariableClAutopartitionScheme(AutopartitionHelper, Variable):
         return [
             (SchemeOpt.Swap, _("Swap partition")),
             (SchemeOpt.Update, _("The partition for the update")),
-            (SchemeOpt.Calculate, _("/var/calculate partition")),
+            (SchemeOpt.Calculate, _("Data partition")),
             (SchemeOpt.UEFI, _("Use the UEFI bootloader")),
             (SchemeOpt.LVM, _("Use LVM")),
         ]
