@@ -679,17 +679,25 @@ class VariableOsInstallNetRoute(NetHelper, ReadonlyVariable):
 
         def getRouteForInterfaceConf(interface, net, routeMatrix):
             NET, GW, DEV, SRC = 0, 1, 2, 3
-            return "\n".join(
-                # build string for route from net,gateway,dev and src
-                map(lambda x: "{net}{gateway}{src}".format(
+            # filter by interface and discard direct routes
+            # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
+            route_list = filter(lambda x: (interface == x[DEV] or defaultDev and
+                                      interface == defaultDev) \
+                                     and net != x[NET], routeMatrix)
+
+            nets = []
+            route_list_uniqnet = []
+            for net, gw, dev, src in route_list:
+                if net not in nets:
+                    route_list_uniqnet.append([net, gw, dev, src])
+                    nets.append(net)
+
+            route_strs = map(lambda x: "{net}{gateway}{src}".format(
                     net=x[NET],
                     gateway=" via %s" % x[GW] if x[GW] else "",
-                    src=" src %s" % x[SRC] if x[SRC] else ""),
-                    # filter by interface and discard direct routes
-                    # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
-                    filter(lambda x: (interface == x[DEV] or defaultDev and
-                                      interface == defaultDev) \
-                                     and net != x[NET], routeMatrix)))
+                    src=" src %s" % x[SRC] if x[SRC] else ""), route_list_uniqnet)
+            # build string for route from net,gateway,dev and src
+            return "\n".join(route_strs)
 
         return self.performRouteData(getRouteForInterfaceConf)
 
